@@ -201,14 +201,8 @@ tar_rep2_run <- function(command, batches, iteration, rep_workers) {
 #' # See the examples of tar_rep2().
 tar_rep2_run_rep <- function(rep, slice, command, batch, seeds, envir) {
   seed <- as.integer(if_any(anyNA(seeds), NA_integer_, seeds[rep]))
-  out <- if_any(
-    anyNA(seed),
-    eval(command, envir = slice, enclos = envir),
-    withr::with_seed(
-      seed = seed,
-      code = eval(command, envir = slice, enclos = envir)
-    )
-  )
+  if_any(anyNA(seed), NULL, tar_seed_set(seed = seed))
+  out <- eval(command, envir = slice, enclos = envir)
   out$tar_batch <- as.integer(batch)
   out$tar_rep <- as.integer(rep)
   out$tar_seed <- as.integer(seed)
