@@ -1,5 +1,5 @@
 targets::tar_test("tar_knit_raw() works", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
@@ -44,7 +44,7 @@ targets::tar_test("tar_knit_raw() works", {
 })
 
 targets::tar_test("tar_knit_raw() warns about tar_read_raw()", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
@@ -70,7 +70,7 @@ targets::tar_test("tar_knit_raw() warns about tar_read_raw()", {
 })
 
 targets::tar_test("tar_knit_raw() warns about tar_load_raw()", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
@@ -97,7 +97,7 @@ targets::tar_test("tar_knit_raw() warns about tar_load_raw()", {
 })
 
 targets::tar_test("tar_knit_raw(nested) runs from the project root", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
